package com.ruoyi.web.plotmanage.mapper;


import com.ruoyi.web.plotmanage.domain.AdPlot;

import java.util.List;


/**
 * 小区管理Mapper接口
 *
 * @author cyx
 * @date 2022-11-23
 */
public interface AdPlotMapper
{
    /**
     * 查询小区管理
     *
     * @param id 小区管理主键
     * @return 小区管理
     */
    public AdPlot selectAdPlotById(String id);

    /**
     * 查询小区管理列表
     *
     * @param adPlot 小区管理
     * @return 小区管理集合
     */
    public List<AdPlot> selectAdPlotList(AdPlot adPlot);

    /**
     * 新增小区管理
     *
     * @param adPlot 小区管理
     * @return 结果
     */
    public int insertAdPlot(AdPlot adPlot);

    /**
     * 修改小区管理
     *
     * @param adPlot 小区管理
     * @return 结果
     */
    public int updateAdPlot(AdPlot adPlot);

    /**
     * 删除小区管理
     *
     * @param id 小区管理主键
     * @return 结果
     */
    public int deleteAdPlotById(String id);

    /**
     * 批量删除小区管理
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAdPlotByIds(String[] ids);
}
